#include "LED.cpp"
#include "BluetoothLEDCallback.cpp"
#include "BluetoothService.cpp"
#include <Arduino.h>

#define FADE_IN_DURATION 500
#define FADE_OUT_DURATION 2000

LEDOutput _seatingLedOutput(0, true);
LED _seatingLeds("seating", &_seatingLedOutput, FADE_IN_DURATION, FADE_OUT_DURATION);
LEDOutput _kitchenLedOutput(1 , true);
LED _kitchenLeds("kitchen", &_kitchenLedOutput, FADE_IN_DURATION, FADE_OUT_DURATION);
LEDOutput _bathroomLedOutput(2 , true);
LED _bathroomLeds("bathroom", &_bathroomLedOutput, FADE_IN_DURATION, FADE_OUT_DURATION);

TimerManager _timers;
JsonLightControl _jsonLightControl(&_timers);
BluetoothLEDCallback _btCallback(&_jsonLightControl);
BluetoothService _btService("Van Lights", &_btCallback);

void setup() {
	Serial.begin(115200);
	_seatingLedOutput.attach(16);
	_seatingLedOutput.attach(17);

	_kitchenLedOutput.attach(5);
	_kitchenLedOutput.attach(18);
	_kitchenLedOutput.attach(23);

	_bathroomLedOutput.attach(19);

	_timers.add(_seatingLeds.getName(), [](){ _seatingLeds.off(); });
	_timers.add(_kitchenLeds.getName(), [](){ _kitchenLeds.off(); });
	_timers.add(_bathroomLeds.getName(), [](){ _bathroomLeds.off(); });

	_jsonLightControl.registerLEDs(&_seatingLeds);
	_jsonLightControl.registerLEDs(&_kitchenLeds);
	_jsonLightControl.registerLEDs(&_bathroomLeds);

	_btService.init();
	_btService.start();
}

void loop() {
	_timers.loop();
	_seatingLeds.loop();
	_kitchenLeds.loop();
	_bathroomLeds.loop();
}
